#[non_exhaustive]pub enum EncoderError {
NonFiniteRate {
parameter: &'static str,
},
RateOrder,
InvalidRange {
parameter: &'static str,
},
CountMustBePositive {
parameter: &'static str,
},
NonPositiveOrNonFinite {
parameter: &'static str,
},
NonNegativeFinite {
parameter: &'static str,
},
NumChannelsTooLarge,
HistoryDepthTooSmall {
minimum: usize,
},
StateLengthMismatch {
left: &'static str,
right: &'static str,
},
HistoryLengthExceedsDepth {
channel: usize,
},
WindowMustBePositive {
parameter: &'static str,
},
}Expand description
Stable error type returned by fallible encoder constructors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonFiniteRate
A rate parameter must be finite.
RateOrder
base_rate must not exceed max_rate.
InvalidRange
Numeric range bounds must be finite and strictly increasing.
CountMustBePositive
Count parameters must be positive.
NonPositiveOrNonFinite
A threshold/tuning-width style parameter must be finite and positive.
NonNegativeFinite
A parameter must be finite and non-negative (>= 0).
NumChannelsTooLarge
Channel/neuron count exceeds the u16 channel-ID range used when emitting spikes.
HistoryDepthTooSmall
Temporal history depth is too small for the encoder window.
StateLengthMismatch
A deserialized state vector has inconsistent lengths.
HistoryLengthExceedsDepth
A deserialized history channel contains more samples than allowed by history_depth.
WindowMustBePositive
Cycle/window parameters must be non-zero.