pub struct DerivativeEncoder { /* private fields */ }Expand description
Encodes based on the rate of change (derivative) of the input.
Fires an excitatory spike when the positive change exceeds a threshold, and an inhibitory spike when the negative change exceeds the threshold.
Examples
use axon_encoder::prelude::*;
let mut enc = DerivativeEncoder::try_new(vec![0.2])?;
let _ = enc.encode_step(&[0.0]); // seed previous sample
let out = enc.encode_step(&[0.5]); // +0.5 change exceeds threshold
assert_eq!(out.spikes.len(), 1);
assert!(out.spikes[0].polarity);Implementations
Sourceimpl DerivativeEncoder
impl DerivativeEncoder